httpcore: A minimal low-level HTTP client.
==========================================

Description
-----------

A minimal low-level HTTP client.

License
-------

Upstream Contact
----------------

https://pypi.org/project/httpcore/

